@@ -26,7 +26,7 @@
 using namespace libebml;
 using namespace libmatroska;
 
-namespace mtx { namespace tags {
+namespace mtx::tags {
 
 KaxTags *
 select_for_chapters(KaxTags &tags,
@@ -110,13 +110,13 @@ get_simple_value(const std::string &name,
 std::string
 get_simple_name(const KaxTagSimple &tag) {
   KaxTagName *tname = FindChild<KaxTagName>(&tag);
-  return tname ? tname->GetValueUTF8() : std::string{""};
+  return tname ? tname->GetValueUTF8() : ""s;
 }
 
 std::string
 get_simple_value(const KaxTagSimple &tag) {
   KaxTagString *tstring = FindChild<KaxTagString>(&tag);
-  return tstring ? tstring->GetValueUTF8() : std::string{""};
+  return tstring ? tstring->GetValueUTF8() : ""s;
 }
 
 void
@@ -326,8 +326,10 @@ remove_elements_unsupported_by_webm(EbmlMaster &master) {
       if (sub_master)
         remove_elements_unsupported_by_webm(*sub_master);
 
-    } else
+    } else {
+      delete master[idx];
       master.Remove(idx);
+    }
   }
 }
 
@@ -379,4 +381,4 @@ remove_track_statistics(KaxTags *tags,
   return removed_something;
 }
 
-}}
+}
