@@ -295,46 +295,17 @@ kax_track_t::discard_track_statistics_tags() {
    Probes a file by simply comparing the first four bytes to the EBML
    head signature.
 */
-int
-kax_reader_c::probe_file(mm_io_c &in,
-                         uint64_t size) {
+bool
+kax_reader_c::probe_file() {
   unsigned char data[4];
-
-  if (4 > size)
-    return 0;
-  try {
-    in.setFilePointer(0);
-    if (in.read(data, 4) != 4)
-      return 0;
-    in.setFilePointer(0);
-  } catch (...) {
-    return 0;
-  }
-  if (get_uint32_be(data) != MAGIC_MKV)
-    return 0;
-  return 1;
+  return (m_in->read(data, 4) == 4) && (get_uint32_be(data) == MAGIC_MKV);
 }
 
-kax_reader_c::kax_reader_c(const track_info_c &ti,
-                           const mm_io_cptr &in)
-  : generic_reader_c(ti, in)
-  , m_segment_duration(0)
-  , m_last_timestamp(0)
-  , m_global_timestamp_offset{}
-  , m_writing_app_ver(-1)
-  , m_attachment_id(0)
-  , m_file_status(FILE_STATUS_MOREDATA)
-  , m_opus_experimental_warning_shown{}
-  , m_regenerate_chapter_uids{}
-  , m_debug_minimum_timestamp{"kax_reader|kax_reader_minimum_timestamp"}
-{
+kax_reader_c::kax_reader_c() {
   init_l1_position_storage(m_deferred_l1_positions);
   init_l1_position_storage(m_handled_l1_positions);
 }
 
-kax_reader_c::~kax_reader_c() {
-}
-
 void
 kax_reader_c::init_l1_position_storage(deferred_positions_t &storage) {
   storage[dl1t_attachments] = std::vector<int64_t>();
@@ -893,7 +864,6 @@ kax_reader_c::handle_attachments(mm_io_c *io,
 
     if (   !matt->data->get_size()
         || matt->mime_type.empty()
-        || matt->name.empty()
         || (ATTACH_MODE_SKIP == attach_mode))
       continue;
 
@@ -2130,7 +2100,7 @@ kax_reader_c::create_packetizer(int64_t tid) {
   }
 
   set_packetizer_headers(t);
-  m_ptzr_to_track_map[ m_reader_packetizers[t->ptzr] ] = t;
+  m_ptzr_to_track_map[ PTZR(t->ptzr) ] = t;
 }
 
 void
@@ -2332,7 +2302,7 @@ kax_reader_c::process_simple_block(KaxCluster *cluster,
 
   if (!block_track) {
     mxwarn_fn(m_ti.m_fname,
-              fmt::format(Y("A block was found at timestamp {0} for track number {1}. However, no headers where found for that track number. "
+              fmt::format(Y("A block was found at timestamp {0} for track number {1}. However, no headers were found for that track number. "
                             "The block will be skipped.\n"), format_timestamp(block_timestamp), block_simple->TrackNum()));
     return;
   }
@@ -2440,7 +2410,7 @@ kax_reader_c::process_block_group(KaxCluster *cluster,
 
   if (!block_track) {
     mxwarn_fn(m_ti.m_fname,
-              fmt::format(Y("A block was found at timestamp {0} for track number {1}. However, no headers where found for that track number. "
+              fmt::format(Y("A block was found at timestamp {0} for track number {1}. However, no headers were found for that track number. "
                             "The block will be skipped.\n"), format_timestamp(block_timestamp), block->TrackNum()));
     return;
   }
