@@ -67,10 +67,11 @@ public:
   void sendArgumentsToRunningInstance(QStringList const &args);
   void raiseAndActivateRunningInstance();
 
-  void maybeEnableDarkStyleSheet();
-
   void run();
 
+  void disableDarkMode();
+  void enableDarkMode();
+
   Util::NetworkAccessManager &networkAccessManager();
 
 signals:
@@ -83,6 +84,7 @@ signals:
 public slots:
   void saveSettings() const;
   void receiveInstanceCommunication();
+  void setupColorMode();
 
 protected:
   void setupInstanceCommunicator();
