@@ -22,7 +22,7 @@
 using namespace libmatroska;
 using namespace mtx::gui;
 
-namespace mtx { namespace gui { namespace HeaderEditor {
+namespace mtx::gui::HeaderEditor {
 
 AttachedFilePage::AttachedFilePage(Tab &parent,
                                    PageBase &topLevelPage,
@@ -98,7 +98,8 @@ AttachedFilePage::dropEvent(QDropEvent *event) {
 QString
 AttachedFilePage::title()
   const {
-  return Q(FindChildValue<KaxFileName>(*m_attachment, to_wide(Y("<Unnamed>"))));
+  auto name = Q(FindChildValue<KaxFileName>(*m_attachment));
+  return !name.isEmpty() ? name : QY("<Unnamed>");
 }
 
 void
@@ -229,4 +230,4 @@ AttachedFilePage::replaceContent(bool deriveNameAndMimeType) {
   Util::setComboBoxTextByData(ui->mimeType, mimeType);
 }
 
-}}}
+}
