@@ -70,6 +70,7 @@ char const * const s_valMergeLastRelativeOutputDirs         = "mergeLastRelative
 char const * const s_valMergePredefinedSplitDurations       = "mergePredefinedSplitDurations";
 char const * const s_valMergePredefinedSplitSizes           = "mergePredefinedSplitSizes";
 char const * const s_valMergePredefinedTrackNames           = "mergePredefinedTrackNames";
+char const * const s_valMergeSetDestinationFromTitle        = "mergeSetDestinationFromTitle";
 char const * const s_valMergeTrackPropertiesLayout          = "mergeTrackPropertiesLayout";
 char const * const s_valMergeUseVerticalInputLayout         = "mergeUseVerticalInputLayout";
 char const * const s_valMergeWarnMissingAudioTrack          = "mergeWarnMissingAudioTrack";
@@ -101,6 +102,7 @@ char const * const s_valSwitchToJobOutputAfterStarting      = "switchToJobOutput
 char const * const s_valTabPosition                         = "tabPosition";
 char const * const s_valTrackInfo                           = "trackInfo";
 char const * const s_valType                                = "type";
+char const * const s_valUiDisableDarkStyleSheet             = "uiDisableDarkStyleSheet";
 char const * const s_valUiDisableHighDPIScaling             = "uiDisableHighDPIScaling";
 char const * const s_valUiFontFamily                        = "uiFontFamily";
 char const * const s_valUiFontPointSize                     = "uiFontPointSize";
