@@ -1,9 +1,6 @@
-#ifndef MTX_TYPES_H
-#define MTX_TYPES_H
+#pragma once
 
 #include "common/common_pch.h"
 
 using MediaTime = int64_t;
 using binary    = uint8_t;
-
-#endif // MTX_TYPES_H
